#version 330

/** Input variable (the position, which is vertex attribute 0) */
layout(location = 0) in vec4 vertex_position;

/** Input variable (the normal, which is vertex attribute 1) (NOT USED HERE) */
layout(location = 1) in vec4 vertex_normal;

/** Input variable (the color, which is vertex attribute 2) */
layout(location = 2) in vec4 vertex_color;

/** Input variable (the uv, which is vertex attribute 3) (NOT USED HERE) */
layout(location = 3) in vec4 vertex_texCoord;

/**
 * Output variable in which we write the rgb color. This
 * variable is forwarded to the fragment shader.
 */
out vec4 color_from_vs;

/**
 * Contains the position of the cube which we computed via rasterization
 * 
 */
uniform vec4 position;

/**
 * Using a model matrix (this allows to view the cube from different
 * sides in this exercise).
 */
uniform mat4 model;

/**
 * The main function of the vertex shader, which is executed
 * for every vertex.
 */
void main()
{
    color_from_vs = vertex_color;

    // gl_Position is a predefined variable in every vertex
    // shader which has to get a value. We set it as a combination of the vertex position and the position of the cube which we computed with our rasterization algorithm 
    vec4 position = position + vertex_position;

    gl_Position = model * position;
}
